#
# spec file for package shibboleth-sp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libvers 12
%define libvers_lite 12
%define runuser shibd
%define realname shibboleth
%define pkgdocdir %{_docdir}/%{realname}
Name:           shibboleth-sp
Version:        3.5.0
Release:        1.3
Summary:        System for attribute-based Web Single Sign On
License:        Apache-2.0
Group:          Productivity/Networking/Security
URL:            https://shibboleth.net/
Source0:        https://shibboleth.net/downloads/service-provider/%{version}/%{name}-%{version}.tar.bz2
Source1:        https://shibboleth.net/downloads/service-provider/%{version}/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Source3:        shibd.service
Patch0:         shibboleth-sp-2.5.5-doxygen_timestamp.patch
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  krb5-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  liblog4shib-devel >= 2
BuildRequires:  libmemcached-devel
BuildRequires:  libsaml-devel >= 3.1.0
BuildRequires:  libtool
BuildRequires:  libxerces-c-devel >= 3.2
BuildRequires:  libxml-security-c-devel >= 2.0.0
BuildRequires:  libxmltooling-devel >= 3.1.0
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  unixODBC-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libsystemd)
Requires:       openssl
Requires(pre):  opensaml-schemas >= 3.1.0
Requires(pre):  xmltooling-schemas >= 3.1.0
Requires(pre):  shadow
Obsoletes:      shibboleth-sp = 2.5.0
%{?systemd_requires}

%description
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains the Shibboleth Service Provider runtime libraries,
daemon, default plugins, and Apache module.

%package -n libshibsp%{libvers}
Summary:        Shared Library for Shibboleth
Group:          Productivity/Networking/Security

%description -n libshibsp%{libvers}
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains just the shared library.

%package -n libshibsp-lite%{libvers_lite}
Summary:        Shared Library for Shibboleth
Group:          Productivity/Networking/Security

%description -n libshibsp-lite%{libvers_lite}
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains just the shared library.

%package devel
Summary:        Shibboleth Development Headers
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       liblog4shib-devel >= 2
Requires:       libsaml-devel >= 3.1.0
Requires:       libshibsp%{libvers} = %{version}-%{release}
Requires:       libshibsp-lite%{libvers_lite} = %{version}-%{release}
Requires:       libxerces-c-devel >= 3.2
Requires:       libxml-security-c-devel >= 2.0.0
Requires:       libxmltooling-devel >= 3.1.0
Obsoletes:      shibboleth-sp-devel = 2.5.0

%description devel
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package includes files needed for development with Shibboleth.

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} --std=c++11"
autoreconf -f -i
%configure --with-gssapi --enable-systemd --with-memcached
%make_build pkgdocdir=%{pkgdocdir}

%install
%make_install NOKEYGEN=1 pkgdocdir=%{pkgdocdir}

install -D -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/shibd.service
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rcshibd

sed -i "s|/var/log/httpd|/var/log/apache2|g" \
		%{buildroot}%{_sysconfdir}/%{realname}/native.logger

sed -i "s|%{_bindir}/env bash|%{_bindir}/bash|" \
		%{buildroot}%{_sysconfdir}/%{realname}/metagen.sh

# Delete unnecessary files
pushd %{buildroot}/%{_sysconfdir}/%{realname}
rm shibd-debian shibd-redhat shibd-amazon shibd-suse shibd-osx.plist apache.config apache2.config apache22.config shibd-systemd
rm *.dist
popd
find %{buildroot} -type f -name "*.la" -delete -print

# Plug the SP into the Apache
touch rpm.filelist
APACHE_CONFIG="no"
if [ -f %{buildroot}%{_libdir}/%{realname}/mod_shib_24.so ] ; then
	APACHE_CONFIG="apache24.config"
fi

if [ "$APACHE_CONFIG" != "no" ] ; then
	APACHE_CONFD="no"
	if [ -d %{_sysconfdir}/apache2/conf.d ] ; then
		APACHE_CONFD="%{_sysconfdir}/apache2/conf.d"
	fi
	if [ "$APACHE_CONFD" != "no" ] ; then
		mkdir -p $RPM_BUILD_ROOT$APACHE_CONFD
		cp -p %{buildroot}%{_sysconfdir}/%{realname}/$APACHE_CONFIG $RPM_BUILD_ROOT$APACHE_CONFD/shib.conf
		echo "%config(noreplace) $APACHE_CONFD/shib.conf" >> rpm.filelist
	fi
fi

# Get run directory created at boot time.
mkdir -p %{buildroot}%{_tmpfilesdir}
echo "%attr(0444,-,-) %{_tmpfilesdir}/%{realname}.conf" >> rpm.filelist
cat > %{buildroot}%{_tmpfilesdir}/%{realname}.conf <<EOF
d /run/%{realname} 755 %{runuser} %{runuser} -
EOF

cat > %{realname}.sysusers << EOF
u %{runuser} - "Shibboleth SP daemon" /run/%{realname} /dev/nologin
EOF
%sysusers_generate_pre %{realname}.sysusers %{name} %{name}.conf

install -Dpm0644 %{realname}.sysusers %{buildroot}%{_sysusersdir}/%{name}.conf

%check
%make_build check

%pre -f %{name}.pre
%service_add_pre shibd.service
exit 0

%post -n libshibsp%{libvers} -p /sbin/ldconfig
%post -n libshibsp-lite%{libvers_lite} -p /sbin/ldconfig

%post

# Generate two keys on new installs.
if [ $1 -eq 1 ] ; then
        cd %{_sysconfdir}/shibboleth
        /bin/sh ./keygen.sh -b -n sp-signing -u %{runuser} -g %{runuser}
        /bin/sh ./keygen.sh -b -n sp-encrypt -u %{runuser} -g %{runuser}
fi

%service_add_post shibd.service

%tmpfiles_create %{_tmpfilesdir}/%{realname}.conf

%preun
# On final removal, stop shibd and remove service, restart Apache if running.
%service_del_preun shibd.service
if [ $1 -eq 0 ] ; then
	/sbin/service apache2 status 1>/dev/null && /sbin/service apache2 restart 1>/dev/null
fi
exit 0

%postun -n libshibsp%{libvers} -p /sbin/ldconfig
%postun -n libshibsp-lite%{libvers_lite} -p /sbin/ldconfig

%postun
%service_del_postun shibd.service
%restart_on_update apache2

%posttrans
# One-time extra restart of shibd and Apache to work around
# SUSE bug that breaks old %%restart_on_update macro.
# If we remove, upgrades from pre-systemd to post-systemd
# will stop doing the final restart.
%{_bindir}/systemctl try-restart shibd >/dev/null 2>&1 || :
%{_bindir}/systemctl try-restart apache2 >/dev/null 2>&1 || :
exit 0

%files -f rpm.filelist
%{_sbindir}/shibd
%{_sbindir}/rcshibd
%{_bindir}/mdquery
%{_bindir}/resolvertest
%dir %{_libdir}/%{realname}
%{_libdir}/%{realname}/*
%{_unitdir}/shibd.service
%{_sysusersdir}/%{name}.conf
%attr(0750,%{runuser},%{runuser}) %dir %{_localstatedir}/log/%{realname}
%attr(0755,%{runuser},%{runuser}) %dir %{_localstatedir}/cache/%{realname}
%ghost %attr(0755,%{runuser},%{runuser}) %dir /run/%{realname}
%dir %{_datadir}/xml/%{realname}
%{_datadir}/xml/%{realname}/*
%dir %{_datadir}/%{realname}
%{_datadir}/%{realname}/*
%dir %{_sysconfdir}/%{realname}
%config(noreplace) %{_sysconfdir}/%{realname}/*.xml
%config(noreplace) %{_sysconfdir}/%{realname}/*.html
%config(noreplace) %{_sysconfdir}/%{realname}/*.logger
%{_tmpfilesdir}/%{realname}.conf
%{_sysconfdir}/%{realname}/apache24.config
%attr(0755,root,root) %{_sysconfdir}/%{realname}/keygen.sh
%attr(0755,root,root) %{_sysconfdir}/%{realname}/metagen.sh
%attr(0755,root,root) %{_sysconfdir}/%{realname}/seckeygen.sh
%doc %{pkgdocdir}
%exclude %{pkgdocdir}/api

%files -n libshibsp%{libvers}
%{_libdir}/libshibsp.so.*

%files -n libshibsp-lite%{libvers_lite}
%{_libdir}/libshibsp-lite.so.*

%files devel
%{_includedir}/*
%{_libdir}/libshibsp.so
%{_libdir}/libshibsp-lite.so
%{_libdir}/pkgconfig/*.pc
%doc %{pkgdocdir}/api

%changelog
* Wed Nov  6 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 3.5.0:
  * This is a small update to address a few bugs, update a number of libraries,
    and implement a correction to the default signing algorithm used when
    issuing signed requests via the SAML POST binding. This was inadvertently
    still defaulting to RSA-SHA1 and should have been using RSA-SHA256.
    There is the unlikely possibility of this causing interoperability issues
    with badly out of date Identity Providers, so is another reason for
    releasing it as a minor update.
* Fri Feb  9 2024 Daniel Molkentin <daniel@molkentin.de>
- create correct user name runuser, not realname
* Mon Feb  5 2024 Daniel Molkentin <daniel@molkentin.de>
- Update to use sysuser pattern
- Fix build warnings
* Tue Jan 17 2023 Dirk Müller <dmueller@suse.com>
- update to 3.4.1:
  * Reinforcing the xmltooling library (V3.2.3, included in this Windows release)
    to block an unnecessary XML Encryption construct, related to the advisory
    issued for the IdP recently. The SP is not believed to be vulnerable, but this
    is a defensive measure.
  * A warning has been added to the log when systems do not configure an explicit
    value for the redirectLimit setting. The default for this setting remains
    liberal for compatibility, so the warning was requested to highlight that
    fact.
* Thu Nov 17 2022 Danilo Spinella <danilo.spinella@suse.com>
- Updaet to 3.4.0:
  * Add a new setting suggested controlling retries when TCP connections
  to shibd are used.
- Change libraries soname from 10 to 11
* Wed Dec  1 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 3.3.0:
  * This is a minor update that contains a small number of fixes,
    one small feature addition, and a number of additional deprecation
    warnings for at risk features.
* Wed Nov 17 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * shibd.service
* Tue Jul 13 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 3.2.3:
  * This is a minor update that includes some minimal new functionality and addresses some bugs.
  * Fix two different security bugs (secadv_20210317 and secadv_20210426)
- Run spec-cleaner
- Change library soname from 9 to 10
- Change lite library soname from 8 to 10
* Tue Dec  1 2020 Kristyna Streitova <kstreitova@suse.com>
- Update to 3.1.0
  * list of fixes and enhancements
    https://wiki.shibboleth.net/confluence/display/SP3/ReleaseNotes
- Update xmltooling and opensaml versions in "Requires"
- Change library soname from 8 to 9
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Rely on the distro-provided macros for tmpfilesdir. All half-way
  current distros define this already.
* Wed Jan  8 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Mon Dec  2 2019 Kristyna Streitova <kstreitova@suse.com>
- remove fixing of the ownership of log files as this allows shibd
  to escalate to root [bsc#1157471] [CVE-2019-19191]
- generate two keys on new installs instead of just one
* Fri Apr 26 2019 mvetter@suse.com
- bsc#1130588: Require shadow instead of old pwdutils
* Wed Mar 20 2019 Kristýna Streitová <kstreitova@suse.com>
- update to 3.0.4
  * list of fixes and enhancements
    https://issues.shibboleth.net/jira/browse/SSPCPP-851?filter=12771
- update xmltooling and opensaml versions in "Requires"
* Mon Feb 11 2019 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies from summary
* Mon Feb 11 2019 kstreitova@suse.com
- update to 3.0.3
  * list of fixes and enhancements
  https://issues.shibboleth.net/jira/browse/SSPCPP-845?filter=12573
* Wed Nov 28 2018 kstreitova@suse.com
- update to 3.0.2
  * list of fixes and enhancements
    https://wiki.shibboleth.net/confluence/display/SP3/ReleaseNotes
- remove shibboleth-sp-2.5.6-libsystemd-daemon.patch that is no
  longer needed
- update package filelist
- change library soname from 7 to 8
- update dependencies versions
* Wed Nov 15 2017 kstreitova@suse.com
- update to 2.6.1
  * list of fixes and enhancements
    https://issues.shibboleth.net/jira/browse/SSPCPP-760?filter=12270
  * fixes [bsc#1068689] [CVE-2017-16852]
* Thu Sep 21 2017 kstreitova@suse.com
- update to 2.6.0
  * list of fixes and enhancements
    https://issues.shibboleth.net/jira/browse/SSPCPP-716?filter=11475
- update soname for libshibsp from 6 to 7
- adjust BuildRequires of boost
  * libboost_headers-devel for openSUSE:Factory
  * boost-devel for older distros
- update versions of BuildRequires for opensaml (>= 2.6.0) and
  libxmltooling (>= 1.6.0)
- shibd.service: increase TimeoutStartSec to 150s (as upstream did)
- remove %%{_sysconfdir}/%%{realname}/*.xsl from filelist (it is no
  longer present)
- run spec-cleaner
* Thu Mar 16 2017 kstreitova@suse.com
- fix build for openSUSE:Leap:42.1 by adding %%define for
  tmpfiles_create as this macro doesn't exist there
* Tue Feb 14 2017 kstreitova@suse.com
- add shibboleth-sp-2.5.6-libsystemd-daemon.patch to fix configure
  to use libsystemd instead of obsolete libsystemd-daemon.
  Regenerate configure via autoreconf and add autoconf and automake
  BuildRequires.
* Tue Jul 19 2016 dimstar@opensuse.org
- Use %%tmpfiles_create macro: gracefully fails in case of missing
  binaries (e.g. container setups).
* Wed May 11 2016 kstreitova@suse.com
- build libmemcached support
* Fri Apr  8 2016 kstreitova@suse.com
- update to shibboleth-sp 2.5.6
  * Update solution file after loading into VS2015
  * SSPCPP-669 - cached samlds.json files prematurely removed w/ multiple
  * applicationIds
  * SSPCPP-671 - Handling of partial success in LogoutResponse needs work
  * Fix line feeds again, VS is also broken
  * SSPCPP-670 - Session Cleanup for Database Session Storage can cause performance issues
  * Re-convert linefeeds to undo Eclipse's handiwork
  * SSPCPP-675 - configuration sample cites "federation.org"
  * Clean up ignores
  * Apply typo fixes provided by Debian packagers
  * Update library/software version
  * Update MSI names to carry patch version
  * SSPCPP-665 - Use of systemd breaks on reboot
* Wed Aug  5 2015 mpluskal@suse.com
- Add gpg signature
* Thu Jul 30 2015 kstreitova@suse.com
- fix some warnings
- add service as a separate file
- remove command line switches for conditional package builds
- remove *.dist files and unused *.config files
- remove unused conditionals
- move libraries to the subpackages
* Mon Jul 27 2015 kstreitova@suse.com
- use spec-cleaner
- package cleaning
- add shibboleth-sp-2.5.5-doxygen_timestamp.patch to remove
  timestamps in a documentation generated by Doxygen and avoid
  RPMLINT warnings (file-contains-date-and-time).
- add the macro %%{realname} and change a name to "shibboleth-sp"
- fix Source address
* Fri Jul 24 2015 kstreitova@suse.com
- initial revision
